@@ -692,6 +692,7 @@ class Fsck(object):
         - Only devices should have a device number
         - symlink size is length of target
         - names are not longer than 255 bytes
+        - All directory entries have a valid mode
         
         Note that none of this is enforced by S3QL. However, as long as S3QL
         only communicates with the UNIX FUSE module, none of the above should
@@ -705,6 +706,22 @@ class Fsck(object):
             in self.conn.query("SELECT id, mode, size, target, rdev "
                                "FROM inodes LEFT JOIN symlink_targets ON id = inode"):
 
+            has_children = self.conn.has_val('SELECT 1 FROM contents WHERE parent_inode=? LIMIT 1',
+                                             (inode,))
+            
+            if stat.S_IFMT(mode) == 0:
+                if has_children:
+                    mode = mode | stat.S_IFDIR
+                    made_to = 'directory'
+                else:
+                    mode = mode | stat.S_IFREG
+                    made_to = 'regular file'
+
+                self.found_errors = True
+                self.log_error('Inode %d (%s): directory entry has no type, changed '
+                               'to %s.', inode, get_path(inode, self.conn), made_to)                    
+                self.conn.execute('UPDATE inodes SET mode=? WHERE id=?', (mode, inode))
+                            
             if stat.S_ISLNK(mode) and target is None:
                 self.found_errors = True
                 self.log_error('Inode %d (%s): symlink does not have target. '
@@ -737,8 +754,7 @@ class Fsck(object):
                                'This is probably going to confuse your system!',
                                inode, get_path(inode, self.conn))
 
-            has_children = self.conn.has_val('SELECT 1 FROM contents WHERE parent_inode=? LIMIT 1',
-                                             (inode,))
+
             if has_children and not stat.S_ISDIR(mode):
                 self.found_errors = True
                 self.log_error('Inode %d (%s) is not a directory but has child entries. '
@@ -751,6 +767,10 @@ class Fsck(object):
                 self.log_error('Inode %d (%s) is not a regular file but has data blocks. '
                                'This is probably going to confuse your system!',
                                inode, get_path(inode, self.conn))
+                
+
+                
+                                
 
         for (name, id_p) in self.conn.query('SELECT name, parent_inode FROM contents_v '
                                             'WHERE LENGTH(name) > 255'):
@@ -1065,7 +1085,6 @@ def main(args=None):
 
     cachepath = get_backend_cachedir(options.storage_url, options.cachedir)
     seq_no = get_seq_no(backend)
-    param_remote = backend.lookup('s3ql_metadata')
     db = None
 
     if os.path.exists(cachepath + '.params'):
@@ -1079,12 +1098,16 @@ def main(args=None):
             db = Connection(cachepath + '.db')
             assert not os.path.exists(cachepath + '-cache') or param['needs_fsck']
 
-        if param_remote['seq_no'] != param['seq_no']:
+        if param['seq_no'] > seq_no:
+            log.warn('File system has not been unmounted cleanly.')
+            param['needs_fsck'] = True
+            
+        elif backend.lookup('s3ql_metadata')['seq_no'] != param['seq_no']:
             log.warn('Remote metadata is outdated.')
             param['needs_fsck'] = True
 
     else:
-        param = param_remote
+        param = backend.lookup('s3ql_metadata')
         assert not os.path.exists(cachepath + '-cache')
         # .db might exist if mount.s3ql is killed at exactly the right instant
         # and should just be ignored.
@@ -1197,7 +1220,7 @@ def main(args=None):
     log.info("Compressing and uploading metadata...")
     obj_fh = backend.perform_write(do_write, "s3ql_metadata", metadata=param,
                                   is_compressed=True)
-    log.info('Wrote %.2f MB of compressed metadata.', obj_fh.get_obj_size() / 1024 ** 2)
+    log.info('Wrote %.2f MiB of compressed metadata.', obj_fh.get_obj_size() / 1024 ** 2)
     pickle.dump(param, open(cachepath + '.params', 'wb'), 2)
 
     db.execute('ANALYZE')
